<?php
include_once(__DIR__.'/iretailapi.php');

class ControllerModuleIRetailOCIRetailApi extends Controller {

	public static $order;

  public function __construct($registry) {
    parent::__construct($registry);
    IRetailApi::config([
        'debug'=>1,
        'power'=>$this->config->get('ociretailapi_power'),
        'mode'=>$this->config->get('ociretailapi_mode'),
        'log'=>$this->config->get('ociretailapi_log'),
        'login'=>$this->config->get('ociretailapi_login'),
        'apikey'=>$this->config->get('ociretailapi_apikey'),
        'printmode'=>$this->config->get('ociretailapi_printmode'),
        'notifymode'=>$this->config->get('ociretailapi_notifymode'),
        'mailer'=>new OCIretailMailer($this->config->get('ociretailapi_emails')),
    ]);
  }

  public function on_order_history_add_pre($order_id) {
    if (IRetailAPI::$power) {
      $this->load->model('account/order');
    	self::$order=$this->model_account_order->getOrder($order_id);

    	// IRetailAPI::debug('pre order='.$order_id.' status='.self::$order['order_status_id']);
    }
  }

  public function on_order_history_add_post($order_id) {
    if (IRetailAPI::$power) {
      $this->load->model('account/order');
      $order=$this->model_account_order->getOrder($order_id);
      // IRetailAPI::debug('post order='.$order_id.' status='.$order['order_status_id']);

      if ($order && !in_array(self::$order['order_status_id'],$this->config->get('ociretailapi_statuses'))
          && in_array($order['order_status_id'],$this->config->get('ociretailapi_statuses')))
        $this->order2iretail($order);
    }
  }

  public function api()
  {
    $ret['status']=false;
    if (isset($this->request->post['order_id']) && isset($this->request->post['refund']))
    {
      $this->load->model('account/order');
      $order=$this->model_account_order->getOrder((int)$this->request->post['order_id']);
      if ($order)
      {
        $ret['status']=$this->order2iretail($order,(int)$this->request->post['refund']);
      }
    }
    $this->response->setOutput(json_encode($ret));
  }

  private function order2iretail($order,$refund=false)
  {
    if (is_scalar($order))
    {
      $this->load->model('account/order');
      $order=$this->model_account_order->getOrder((int)$order);
    }
    if ($order)
    {
      $data = [
        'external_order_id' => $order['order_id'],
        'external_order_time' => gmdate('Y-m-d H:i:s',strtotime($order['date_added'])), ///$order['date_added'],
        'date_time' => gmdate('Y-m-d H:i:s',strtotime($order['date_added'])),
        // 'mode' => 'print_email', по настройке
        'type' => $refund?'refund':'payment',
        'customer_phone' => $order['telephone'],
        'customer_email' => $order['email'],
        'card_amount' =>$this->currency->convert(
          $this->currency->format($order['total'],$order['currency_code'],$order['currency_value'],false),
          $order['currency_code'],'RUR'),
        // 'cash_amount' => 0,
        // 'mc_amount' => 0,
        'purchase' => ['products' => []],
      ];

      $products = $this->model_account_order->getOrderProducts($order['order_id']);
      foreach ($products as $product) {
        $d=[
          'name'=>$product['name'].' '.$product['model'],
          'quantity'=>$product['quantity'],
          'price'=>$this->currency->convert(
            $this->currency->format($product['price'] + ($this->config->get('config_tax') ? $product['tax'] : 0)
              ,$order['currency_code'],$order['currency_value'],false),
            $order['currency_code'],'RUR')
        ];
        if ($this->config->get('config_tax')) {
          $d['vat']=number_format($product['tax']/$product['price'],2,".","");
        }
        $data['purchase']['products'][]=$d;
      }
      $totals= $this->model_account_order->getOrderTotals($order['order_id']);
      // var_dump($totals);die;
      foreach ($totals as $total)
        if (!in_array($total['code'],['sub_total','total','tax']) && $total['value']) {
          $data['purchase']['products'][]=[
            'name'=>$total['title'],
            'quantity'=>1,
            'price'=>$this->currency->convert(
              $this->currency->format($total['value'],$order['currency_code'],$order['currency_value'],false),
              $order['currency_code'],'RUR')
          ];
        }  

      $ret=IRetailAPI::request($data);
      // var_dump($ret);die;

      $this->load->model('checkout/order');
      $this->model_checkout_order->addOrderHistory($order['order_id'],$order['order_status_id'],$ret['text']);

      return $ret['status']=="OK";
    }
    else
      return false;
  }    
}

class OCIretailMailer implements IretailMailerInterface {
  use IretailMailerTrait;

  function notify($subject, $message)
  {
    global $config;
    $mail = new Mail();
    $mail->protocol = $config->get('config_mail_protocol');
    $mail->parameter = $config->get('config_mail_parameter');
    $mail->smtp_hostname = $config->get('config_mail_smtp_hostname');
    $mail->smtp_username = $config->get('config_mail_smtp_username');
    $mail->smtp_password = html_entity_decode($config->get('config_mail_smtp_password'), ENT_QUOTES, 'UTF-8');
    $mail->smtp_port = $config->get('config_mail_smtp_port');
    $mail->smtp_timeout = $config->get('config_mail_smtp_timeout');

    $mail->setFrom($config->get('config_email'));
    $mail->setSender(html_entity_decode($_SERVER['HTTP_HOST'], ENT_QUOTES, 'UTF-8'));
    $mail->setSubject(html_entity_decode($subject, ENT_QUOTES, 'UTF-8'));
    $mail->setText($message);
    foreach ($this->emails as $e)
    {
      $mail->setTo($e);
      $mail->send();
    }
  }
}